<template>
	<el-dialog v-model="dialogVisible" :fullscreen="full" :title="titles" width="50%" draggable @close="resetForm(ruleFormRef)">
		<el-button @click="toggleFullscreen" size="small" class="pot" :icon="FullScreen"></el-button>
		<el-form :model="form" :disabled="disabled" label-width="120px" ref="ruleFormRef" :rules="rules">
			<el-row>
				<el-col :span="11">
					<el-form-item label="责任部门" prop="dutyDepartmentId" size="default">
						<el-tree-select v-model="form.dutyDepartmentId" check-strictly="true" @current-change="dutyName" :data="data" class="w100" :props="propse" placeholder="请选择" />
					</el-form-item>
				</el-col>
				<el-col :span="11" :offset="2">
					<el-form-item label="考核指标" prop="examineValue" size="default">
						<el-input v-model.number="form.examineValue" />
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="11">
					<el-form-item label="制定人部门" prop="makerDepartmentId" size="default">
						<el-tree-select v-model="form.makerDepartmentId" :data="data" check-strictly="true"
										@current-change="makerDepartmentName" class="w100" :props="propse" placeholder="请选择" />
					</el-form-item>
				</el-col>
				<el-col :span="11" :offset="2">
					<el-form-item label="制定日期" prop="makeDate" size="default">
						<el-date-picker v-model="form.makeDate" format="YYYY-MM-DD HH:mm:ss" value-format="YYYY-MM-DD HH:mm:ss" type="datetime" placeholder="请选择" style="width: 100%" />
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="11">
					<el-form-item label="上报值" prop="uploadValue" size="default">
						<el-input v-model="form.uploadValue">
<!--							<template #append> <el-button :icon="Search" @click="openUser" /> </template>-->
            </el-input>
					</el-form-item>
				</el-col>
        <el-col :span="11" :offset="2">
          <el-form-item label="上报时间" prop="uploadDate" size="default">
            <el-date-picker v-model="form.uploadDate" format="YYYY-MM-DD HH:mm:ss" value-format="YYYY-MM-DD HH:mm:ss" type="datetime" placeholder="请选择" style="width: 100%" />
          </el-form-item>
        </el-col>
			</el-row>
      <el-row>
        <el-col :span="11">
          <el-form-item label="考核结果" prop="examineResult" size="default">
			  <el-select v-model="form.examineResult" placeholder="请选择" style="width: 100%">
				  <el-option label="合格" :value="1" />
				  <el-option label="不合格" :value="2" />
			  </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="11" :offset="2">
          <el-form-item label="考核人" prop="examinePersonName" size="default">
            <el-input v-model="form.examinePersonName">
              <template #append> <el-button :icon="Search" @click="openUser" /> </template>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="11">
          <el-form-item label="考核时间" prop="examineDate" size="default">
            <el-date-picker v-model="form.examineDate" format="YYYY-MM-DD HH:mm:ss" value-format="YYYY-MM-DD HH:mm:ss" type="datetime" placeholder="请选择" style="width: 100%" />
          </el-form-item>
        </el-col>
        <el-col :span="11" :offset="2"></el-col>
      </el-row>
		</el-form>
		<template #footer>
			<span class="dialog-footer">

				<el-button @click="resetForm(ruleFormRef)" size="default">关闭</el-button>
				<el-button type="primary" @click="submitForm(ruleFormRef)" size="default">确定</el-button>
			</span>
		</template>
	</el-dialog>
	<DailogSearchUser ref="Show" @SearchUser="onUser"></DailogSearchUser>
</template>
<script lang="ts">
import { defineComponent, ref, reactive, onMounted } from 'vue';
import { Search, FullScreen } from '@element-plus/icons-vue';
import type { FormInstance, FormRules } from 'element-plus';
import DailogSearchUser from '../../../../components/DailogSearchUser/index.vue';
import { ElMessageBox, ElMessage, ElButton, ElInput, TabsPaneContext } from 'element-plus';
import { goalManagementApi } from '/@/api/goalManagement';
export default defineComponent({
	components: { DailogSearchUser },
	setup(props, { emit }) {
		const ruleFormRef = ref<FormInstance>()
		const form = ref({
			"dutyDepartmentId": '', ////责任部门id/外键
			"examineDate": '', ////考核时间
			"examinePersonId": '', ////考核人ID/外键
			"examineResult": '', ////考核结果 1:合格 2：不合格
			"examineValue": '', ////考核指标
			"makeDate": '', ////制定日期
			"makerDepartmentId": '', ////制定部门/外键
			"uploadDate": '', ////上报时间
			"uploadValue": "", ////上报值
		});
		//部门
		const department = () => {
			goalManagementApi()
				.getTreedepartment()
				.then((res) => {
					if (res.data.code == 200) {
						data.value = res.data.data;
					} else {
						ElMessage.error(res.data.msg);
					}
				});
		};
		const propse = {
			label: 'depName',
			children: 'children',
			value: 'depId',
		};
		onMounted(() => {
			department();
		});
		const disabled = ref(false);
		// 开启弹窗
		const titles = ref();
		const dialogVisible = ref(false);
		const openDailog = (title: string, data: any) => {
			titles.value = `${title}目标考核`;
			if (title == '查看') {
				disabled.value = true;
				form.value = data;
			} else if (title == '修改') {
				disabled.value = false;
				form.value = data;
			} else {
				disabled.value = false;
			}
			dialogVisible.value = true;
		};
		// 开启用户弹窗
		const Show = ref();
		const openUser = () => {
			Show.value.openDailog();
		};
		const rules = reactive<FormRules>({
			dutyDepartmentId: [
				{
					required: true,
					message: '责任部门不能为空',
					trigger: 'blur',
				},
			],
			makerDepartmentId: [
				{
					required: true,
					message: '制定人部门不能为空',
					trigger: 'blur',
				},
			],
			commitPersonId: [
				{
					required: true,
					message: '上报人不能为空',
					trigger: 'blur',
				},
			],
			examineValue: [
				{
					required: true,
					message: '考核指标值不能为空',
					trigger: 'blur',
				},
				{
					type: 'number',
					message: '考核指标值只能为数字类型',
					trigger: 'blur',
				},
			],
			makeDate: [
				{
					required: true,
					message: '制定日期不能为空',
					trigger: 'blur',
				},
			],
			commitPersonName: [],
		});
		const dutyName=(data:any)=>{
			form.value.dutyDepartmentName=data.depName
		}
		const makerDepartmentName=(data:any)=>{
			form.value.makerDepartmentName=data.depName
		}

		const submitForm = async (formEl: FormInstance | undefined) => {
			if (!formEl) return;
			await formEl.validate((valid, fields) => {
				if (valid) {
					emit('onAdd', form.value);
					dialogVisible.value = false;
					// handleClose(formEl)
				} else {
					console.log('error submit!', fields);
				}
			});
		};

		const resetForm = (formEl: FormInstance | undefined) => {
			// console.log(formEl);
			if (!formEl) return
			formEl.resetFields();
			dialogVisible.value = false;
			form.value={}
		};
		// const handleClose = (formEl: any) => {
		// 	formEl.resetFields();
		// };
		//全屏
		const full = ref(false);
		const toggleFullscreen = () => {
			if (full.value == false) {
				full.value = true;
			} else {
				full.value = false;
			}
		};
		const data = ref();
		const onUser = (e: any) => {
			console.log(e)
			form.value.examinePersonId = e.uid;
			form.value.examinePersonName = e.realName;
		};
		return {
			disabled,
			titles,
			// handleClose,
			form,
			propse,
			department,
			dialogVisible,
			openDailog,
			Show,
			openUser,
			Search,
			full,
			toggleFullscreen,
			FullScreen,
			data,
			onUser,
			ruleFormRef,
			rules,
			submitForm,
			resetForm,
			dutyName,
			makerDepartmentName
		};
	},
});
</script>
<style scoped>
.el-row {
	padding: 0 0 20px 0;
}
</style>
